Exception raised when encoding fails.
This exception is raised when the encoder encounters an error while converting Elixir data structures to TOON format.
Summary
Functions
Creates a new EncodeError.
Exception raised when encoding fails.
This exception is raised when the encoder encounters an error while converting Elixir data structures to TOON format.
Creates a new EncodeError.